@@ -6,10 +6,10 @@
  * to deal in the Software without restriction, including without limitation
  * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions: 
+ * Software is furnished to do so, subject to the following conditions:
  *
  * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software. 
+ * in all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -39,6 +39,7 @@ DECLARE_CONSTANTS_TYPE(UCharNameChoice);
 DECLARE_CONSTANTS_TYPE(UPropertyNameChoice);
 DECLARE_CONSTANTS_TYPE(UWordBreakValues);
 DECLARE_CONSTANTS_TYPE(UJoiningGroup);
+DECLARE_CONSTANTS_TYPE(ULineBreak);
 #if U_ICU_VERSION_HEX >= VERSION_HEX(52, 0, 0)
 DECLARE_CONSTANTS_TYPE(UBidiPairedBracketType);
 #endif
@@ -46,9 +47,6 @@ DECLARE_CONSTANTS_TYPE(UBidiPairedBracketType);
 
 /* Char */
 
-struct UNone;
-typedef struct UNone UNone;
-
 class t_char : public _wrapper {
 public:
     UNone *object;
@@ -686,7 +684,7 @@ static PyObject *t_char_fn(uchar32_char_fn fn, const char *name,
     {
         UnicodeString result;
         result += (*fn)(u->char32At(0));
-        
+
         return PyUnicode_FromUnicodeString(&result);
     }
 
@@ -734,7 +732,7 @@ static PyObject *t_char_foldCase(PyTypeObject *type, PyObject *args)
         {
             UnicodeString result;
             result += u_foldCase(u->char32At(0), U_FOLD_CASE_DEFAULT);
-        
+
             return PyUnicode_FromUnicodeString(&result);
         }
         break;
@@ -745,7 +743,7 @@ static PyObject *t_char_foldCase(PyTypeObject *type, PyObject *args)
         {
             UnicodeString result;
             result += u_foldCase(u->char32At(0), options);
-        
+
             return PyUnicode_FromUnicodeString(&result);
         }
         break;
@@ -859,6 +857,7 @@ void _init_char(PyObject *m)
     INSTALL_CONSTANTS_TYPE(UPropertyNameChoice, m);
     INSTALL_CONSTANTS_TYPE(UWordBreakValues, m);
     INSTALL_CONSTANTS_TYPE(UJoiningGroup, m);
+    INSTALL_CONSTANTS_TYPE(ULineBreak, m);
 #if U_ICU_VERSION_HEX >= VERSION_HEX(52, 0, 0)
     INSTALL_CONSTANTS_TYPE(UBidiPairedBracketType, m);
 #endif
@@ -984,6 +983,9 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UProperty, "EMOJI_COMPONENT", UCHAR_EMOJI_COMPONENT);
     INSTALL_ENUM(UProperty, "REGIONAL_INDICATOR", UCHAR_REGIONAL_INDICATOR);
     INSTALL_ENUM(UProperty, "PREPENDED_CONCATENATION_MARK", UCHAR_PREPENDED_CONCATENATION_MARK);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(62, 0, 0)
+    INSTALL_ENUM(UProperty, "EXTENDED_PICTOGRAPHIC", UCHAR_EXTENDED_PICTOGRAPHIC);
 #endif
     INSTALL_ENUM(UProperty, "INVALID_CODE ", UCHAR_INVALID_CODE );
 
@@ -1343,6 +1345,19 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UBlockCode, "SOYOMBO", UBLOCK_SOYOMBO);
     INSTALL_ENUM(UBlockCode, "SYRIAC_SUPPLEMENT", UBLOCK_SYRIAC_SUPPLEMENT);
     INSTALL_ENUM(UBlockCode, "ZANABAZAR_SQUARE", UBLOCK_ZANABAZAR_SQUARE);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(62, 0, 0)
+    INSTALL_ENUM(UBlockCode, "CHESS_SYMBOLS", UBLOCK_CHESS_SYMBOLS);
+    INSTALL_ENUM(UBlockCode, "DOGRA", UBLOCK_DOGRA);
+    INSTALL_ENUM(UBlockCode, "GEORGIAN_EXTENDED", UBLOCK_GEORGIAN_EXTENDED);
+    INSTALL_ENUM(UBlockCode, "GUNJALA_GONDI", UBLOCK_GUNJALA_GONDI);
+    INSTALL_ENUM(UBlockCode, "HANIFI_ROHINGYA", UBLOCK_HANIFI_ROHINGYA);
+    INSTALL_ENUM(UBlockCode, "INDIC_SIYAQ_NUMBERS", UBLOCK_INDIC_SIYAQ_NUMBERS);
+    INSTALL_ENUM(UBlockCode, "MAKASAR", UBLOCK_MAKASAR);
+    INSTALL_ENUM(UBlockCode, "MAYAN_NUMERALS", UBLOCK_MAYAN_NUMERALS);
+    INSTALL_ENUM(UBlockCode, "MEDEFAIDRIN", UBLOCK_MEDEFAIDRIN);
+    INSTALL_ENUM(UBlockCode, "OLD_SOGDIAN", UBLOCK_OLD_SOGDIAN);
+    INSTALL_ENUM(UBlockCode, "SOGDIAN", UBLOCK_SOGDIAN);
 #endif
     INSTALL_ENUM(UBlockCode, "INVALID_CODE", UBLOCK_INVALID_CODE);
 
@@ -1382,6 +1397,9 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UWordBreakValues, "E_MODIFIER", U_WB_E_MODIFIER);
     INSTALL_ENUM(UWordBreakValues, "ZWJ", U_WB_ZWJ);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(62, 0, 0)
+    INSTALL_ENUM(UWordBreakValues, "WSEGSPACE", U_WB_WSEGSPACE);
+#endif
 
 #if U_ICU_VERSION_HEX >= 0x04060000
     INSTALL_ENUM(UJoiningGroup, "TEH_MARBUTA_GOAL", U_JG_TEH_MARBUTA_GOAL);
@@ -1447,4 +1465,31 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UJoiningGroup, "MALAYALAM_SSA", U_JG_MALAYALAM_SSA);
     INSTALL_ENUM(UJoiningGroup, "MALAYALAM_TTA", U_JG_MALAYALAM_TTA);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(62, 0, 0)
+    INSTALL_ENUM(UJoiningGroup, "HANIFI_ROHINGYA_KINNA_YA", U_JG_HANIFI_ROHINGYA_KINNA_YA);
+    INSTALL_ENUM(UJoiningGroup, "HANIFI_ROHINGYA_PA", U_JG_HANIFI_ROHINGYA_PA);
+#endif
+
+    INSTALL_ENUM(ULineBreak, "INSEPARABLE", U_LB_INSEPARABLE);
+    INSTALL_ENUM(ULineBreak, "NEXT_LINE", U_LB_NEXT_LINE);
+    INSTALL_ENUM(ULineBreak, "WORD_JOINER", U_LB_WORD_JOINER);
+    INSTALL_ENUM(ULineBreak, "H2", U_LB_H2);
+    INSTALL_ENUM(ULineBreak, "H3", U_LB_H3);
+    INSTALL_ENUM(ULineBreak, "JL", U_LB_JL);
+    INSTALL_ENUM(ULineBreak, "JT", U_LB_JT);
+#if U_ICU_VERSION_HEX >= 0x04040000
+    INSTALL_ENUM(ULineBreak, "CLOSE_PARENTHESIS", U_LB_CLOSE_PARENTHESIS);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(49, 0, 0)
+    INSTALL_ENUM(ULineBreak, "CONDITIONAL_JAPANESE_STARTER", U_LB_CONDITIONAL_JAPANESE_STARTER);
+    INSTALL_ENUM(ULineBreak, "HEBREW_LETTER", U_LB_HEBREW_LETTER);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(50, 0, 0)
+    INSTALL_ENUM(ULineBreak, "REGIONAL_INDICATOR", U_LB_REGIONAL_INDICATOR);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
+    INSTALL_ENUM(ULineBreak, "E_BASE", U_LB_E_BASE);
+    INSTALL_ENUM(ULineBreak, "E_MODIFIER", U_LB_E_MODIFIER);
+    INSTALL_ENUM(ULineBreak, "ZWJ", U_LB_ZWJ);
+#endif
 }
